package mactrans.system;

/**
 * 
 * @author Jan Kienecker (3kieneck@informatik.uni-hamburg.de)
 * @version $Revision: 1.1 $
 * 
 * <pre>
 * $Log: AbstractMachineTranslationClass.java,v $
 * Revision 1.1  2005/01/26 13:42:41  jkieneck
 * added to repository (parent for MTC and XMLDB)
 *
 * </pre>
 */

public abstract class AbstractMachineTranslationClass {
	/* local vars */
	private String _moduleName;
	
	/**
	 * Sets the name of the processing module
	 * 
	 * @param name the name e.g. Parser, Dictionary, etc.
	 */
	public void setModuleName( String name ) {
		if ( _moduleName == null ) {
			_moduleName = new String( name );
		}
	}
	
	/**
	 * Returns the name of the module or produces a fatal error,
	 * if no name is specified.
	 * 
	 * @return the name of the module
	 */
	public String getModuleName() {
		if ( _moduleName == null ) {
			system().fatalError( "MachineTranslationClass", "Modulename was not specified" );
		}
		return _moduleName;
	}
	
	/**
	 * Output (less important) information for the programmer
	 * 
	 * @param message the message produced by the module
	 */
	public void debug( String message ) {
		system().debug( getModuleName(), message );
	}
	
	/**
	 * Output warnings for the programmer/user
	 * 
	 * @param message the message produced by the module
	 */
	public void warn( String message ) {
		system().warn( getModuleName(), message );
	}
	
	/**
	 * Produce an error. Continuation could be tried afterwards
	 * 
	 * @param message the message produced by the module
	 */
	public void error( String message ) {
		system().error( getModuleName(), message ); 
	}
	
	/**
	 * Produce a fatal error. Continuation should not be tried afterwards.
	 * 
	 * @param message the message produced by the module
	 */
	public void fatalError( String message ) {
		system().fatalError( getModuleName(), message );
	}
	
	/**
	 * Tests whether a module is initialized or not.
	 * 
	 * @param o the module/object to test
	 * @return true, if the object is not null
	 */
	public boolean isInitialized( Object o ) {
		return ( o != null );
	}

	/**
	 * 
	 * @return access to the system module
	 */
	public MachineTranslationSystem system() {
		return MachineTranslationKit._system;
	}
}	
