package mactrans.system;

import mactrans.database.*;
import mactrans.parser.*;
import mactrans.alignment.*;
import mactrans.matching.SignBased.*;
import mactrans.matching.aos.*;

/**
 * A sample configuration to work with
 * 
 * @author Jan Kienecker (3kieneck@informatik.uni-hamburg.de)
 * @version $Revision: 1.10 $
 * 
 * <pre>
 * $Log: MachineTranslationConfig1.java,v $
 * Revision 1.10  2005/02/15 17:28:05  jkieneck
 * with alignment enabled
 *
 * Revision 1.9  2005/02/15 14:16:25  jkieneck
 * running without Alignment, because it does not work
 *
 * Revision 1.8  2005/02/15 13:35:03  jkieneck
 * for the full cycle
 *
 * Revision 1.7  2005/02/11 17:52:02  dfriehe
 * increased debug output, fixed ortho
 *
 * Revision 1.6  2005/02/04 15:42:56  dfriehe
 * prepd for mtcore
 *
 * Revision 1.5  2005/02/02 10:23:40  jkieneck
 * for tilly
 *
 * Revision 1.4  2005/02/01 15:35:46  dfriehe
 * prepared for first tests with SampleParser
 *
 * Revision 1.3  2005/01/30 15:54:47  jkieneck
 * added debug method
 *
 * Revision 1.2  2005/01/26 13:43:50  jkieneck
 * adapted to real paths, so that xml loading can be tested
 *
 * Revision 1.1  2005/01/19 13:18:46  jkieneck
 * added to repository
 *
 * </pre>
 */
public class MachineTranslationConfig1 implements MachineTranslationInterface {
	// locals
	private MachineTranslationCore mtCore;
	private String algoStr;
	
	public void debug ( String message ) {
		MachineTranslationKit._system.debug( "System", "--- " + message + " ---" );
	}
	
	public void construct( MachineTranslationSystem mts ) {
		MachineTranslationKit._system = mts;
		debug( "--- MachineTranslation startup ---" );
		
		mtCore = new MachineTranslationCore();
		
		// Creating one for our own purposes
		debug( "--- MachineTranslation startup successfully completed ---" );
	}
	
	public void destruct() {
		// close databases
	}

	public String[] getSourceLanguages() {
		String[] result = new String[2];
		result[0] = "DE";
		result[1] = "EN";
		return result;
	}
	
	public String[] getTargetLanguages() {
		String[] result = new String[2];
		result[0] = "DE";
		result[1] = "EN";
		return result;
	}

	public String[] getAlgorithms() {
		String[] result = new String[3];
		result[0] = "SignBased Matching";
		result[1] = "Angle of Similarity";
		result[2] = "Edit Distance";
		return result;
	}
	
	public void setSourceLanguage( String input ) {
		mtCore.input().setLanguage( input );
	}
	
	public void setTargetLanguage( String input ) {
		mtCore.output().setLanguage( input );
	}
	
	public void setAlgorithm( String input ) {
		algoStr = input;
		if ( input.equals( "SignBased Matching") ) {
			MachineTranslationKit._algorithm = mtCore.signBasedMatching();
		} else {
			if ( input.equals( "Edit Distance") ) {
				MachineTranslationKit._algorithm = mtCore.editDistance();
			} else {
				if ( input.equals( "Angle of Similarity") ) {
					MachineTranslationKit._algorithm = mtCore.wordMatching();
				} else {
					mtCore.debug( "Unknown Algorithm specified ('" + input + "')" );
				}
			}
		}
	}
	
	public void setInputPhrase( String input ) {
		MachineTranslationKit._input.setSentence( input );
	}
	
	public void translate() {
		mtCore.debug( "Calling MTP <" + algoStr + ">" );
		mtCore.callProcessor( mtCore.getMatchingProcessor() );
		
		if ( mtCore.getResultOf( mtCore.getMatchingProcessor() ) != null ) {
			mtCore.debug( "Calling Alignment Processor" );
			mtCore.callProcessor( mtCore.alignment() );
			
			if ( mtCore.getResultOf( mtCore.alignment() ) != null ) {
				mtCore.debug( "Calling Recombination Processor" );
				mtCore.callProcessor( mtCore.recombination() );
				
				if ( mtCore.getResultOf( mtCore.recombination() ) != null ) {
					mtCore.debug( "The translation completed successfully" );
					mtCore.output().setSentence( (String) mtCore.getResultOf( mtCore.recombination() ) );
				} else {
					mtCore.error( "Error(s) in Recombination Processor" );
				}
			} else {
				mtCore.error( "Error(s) in Alignment Processor" );
			}
		} else {
			mtCore.error( "Error(s) in " + algoStr + " Processor" );
		}
	}
	
	public String getOutputPhrase() {
		return mtCore.output().getSentence();
	}
}
