package mactrans.system;

/**
 * Interface GUI <-> System
 * 
 * These methods must be implemented in order to make exchanges
 * between the UI and the system work.
 * 
 * 
 * @author Jan Kienecker (3kieneck@informatik.uni-hamburg.de)
 * @version $Revision: 1.2 $
 * 
 * <pre>
 * $Log: MachineTranslationInterface.java,v $
 * Revision 1.2  2005/01/26 13:44:14  jkieneck
 * extended construct() for better dbg support
 *
 * Revision 1.1  2005/01/19 13:18:30  jkieneck
 * added to repository
 *
 * </pre>
 */

public interface MachineTranslationInterface {
	/**
	 * Init the system
	 *
	 */
	public void construct( MachineTranslationSystem mts );
	
	/**
	 * Destroy the system
	 *
	 */
	public void destruct();
	
	/**
	 * A list of supported source languages
	 * 
	 * @return  a String Array as {EN,DE...}
	 */
	public String[] getSourceLanguages();

	/**
	 * A list of supported target languages
	 * 
	 * @return  a String Array as {EN,DE...}
	 */
	public String[] getTargetLanguages();
	
	/**
	 * A list of supported algorithms
	 * 
	 * @return a String Array such as {EditDistance...}
	 */
	public String[] getAlgorithms();
	
	/**
	 * Tell the system which language is the input language
	 * 
	 * @param input a String such as EN,DE
	 */
	public void setSourceLanguage( String input );
	
	/**
	 * Tell the system which language is the output language
	 * 
	 * @param input a String such as EN,DE
	 */
	public void setTargetLanguage( String input );
	
	/**
	 * Tell the system which algol to use
	 * 
	 * @param input a String such as EditDistance
	 */
	public void setAlgorithm( String input );
	
	/**
	 * Tell the system what's the source of everything...
	 * 
	 * @param input the sentence entered by the user
	 */
	public void setInputPhrase( String input );
	
	/**
	 * Make the system translate based on the given environment
	 *
	 */
	public void translate();
	
	/**
	 * Return the result of all the translation work
	 * 
	 * @return a String (the result)
	 */
	public String getOutputPhrase();
}
