package mactrans.system;

/**
 * MachineTranslationSystem defines action / reaction methods
 * linked to the gui later on.
 *   
 * @author Jan Kienecker (3kieneck@informatik.uni-hamburg.de)
 * @version $Revision: 1.1 $
 * 
 * <pre>
 * $Log: MachineTranslationSystem.java,v $
 * Revision 1.1  2005/01/05 12:56:32  jkieneck
 * added to repository
 *
 * </pre>
 */
public interface MachineTranslationSystem {
	/**
	 * Output (less important) information for the programmer
	 * 
	 * @param module the modulename where the message comes from
	 * @param message the message produced by the module
	 */
	public void debug( String module, String message );

	/**
	 * Output warnings for the programmer/user
	 * 
	 * @param module the modulename where the message comes from
	 * @param message the message produced by the module
	 */
	public void warn( String module, String message );

	/**
	 * Produce an error. Continuation could be tried afterwards
	 * 
	 * @param module the modulename where the message comes from
	 * @param message the message produced by the module
	 */
	public void error( String module, String message );

	/**
	 * Produce a fatal error. Continuation should not be tried afterwards.
	 * 
	 * @param module the modulename where the message comes from
	 * @param message the message produced by the module
	 */
	public void fatalError( String module, String message );
}
