package mactrans.system;

import java.util.HashMap;

/**
 * The Results-Class can be used for obtaining results produced by
 * MachineTranslationProcessors.
 *    
 * @author Jan Kienecker (3kieneck@informatik.uni-hamburg.de)
 * @version $Revision: 1.1 $
 * 
 * <pre>
 * $Log: Results.java,v $
 * Revision 1.1  2005/01/05 11:10:05  jkieneck
 * added to repository
 *
 * </pre>
 */

public class Results {
	/* local vars */
	private HashMap resultMap;
	
	/**
	 * Initializes the Results Class
	 *
	 */
	public Results() {
		resultMap = new HashMap();
	}
	
	/**
	 * This method is used internally to save results produced by
	 * MachineTranslationProcessors.
	 * 
	 * @param m Reference to the MachineTranslationProcessor producing the result
	 * @param result the result produced by the MachineTranslationProcessor
	 */
	public void storeResultOf( MachineTranslationProcessor m, Object result ) {
		resultMap.put( m, result );
	}
	
	/**
	 * Pass the required MachineTranslationProcessor to getResultOf
	 * and it will return the result produced by it, if any.
	 * 
	 * @param m the MachineTranslationProcessor whose results are required
	 * @return Object of any type, or null if no result is linked to the argument
	 */
	public Object getResultOf( MachineTranslationProcessor m ) {
		return resultMap.get( m );
	}
}
